Models¶
The main engine for finding genes, holding the HMM in memory.
Methods:
-
__new__–Initialize the GeneFinder.
-
find_genes–Predict open reading frames in a given DNA sequence.
-
find_genes_batch–Predict open reading frames for a batch of DNA sequences using Rayon.
-
global_model–Exposes the underlying global HMM parameters (read-only).
-
local_models–Exposes the underlying local (GC-specific) HMM parameters (read-only).
-
run_file–Run the full CLI pipeline purely in Rust without python loop overhead.
__new__
¶
__new__(model: Model, whole_genome: Optional[bool] = None) -> GeneFinder
find_genes
¶
find_genes_batch
¶
global_model
¶
global_model() -> HmmGlobal
Exposes the underlying global HMM parameters (read-only).
local_models
¶
local_models() -> list[HmmLocal]
Exposes the underlying local (GC-specific) HMM parameters (read-only).
run_file
¶
run_file(input_path: str, is_fastq: bool, outputs: Mapping[str, str]) -> None
A wrapper around the FragGeneScanRs Global HMM states
Methods:
-
pi–Initial state probabilities
-
tr_ii–Insertion-to-insertion transition matrix [4 x 4]
-
tr_mi–Match-to-insertion transition matrix [4 x 4]
-
transitions–Transition probabilities (MM, MI, MD, II, IM, DD, DM, GE, GG, ER, RS, RR, ES, ES1)
A wrapper around the FragGeneScanRs Local (GC-specific) HMM states
Methods:
-
e_m–Emission probabilities for match states [PERIOD x BI_ACGT x ACGT]
-
e_m1–Emission probabilities for match reverse states [PERIOD x BI_ACGT x ACGT]
-
tr_e–End state transitions [WINDOW x TRI_ACGT]
-
tr_e1–Reverse end state transitions [WINDOW x TRI_ACGT]
-
tr_rr–Background noncoding transition matrix [4 x 4]
-
tr_s–Start state transitions [WINDOW x TRI_ACGT]
-
tr_s1–Reverse start state transitions [WINDOW x TRI_ACGT]